"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeUserToken = exports.storeUserToken = exports.isUserAuthenticated = exports.requestTokens = exports.openDeviceActivationUrl = exports.requestDeviceCode = void 0;
var axios_1 = __importDefault(require("axios"));
var open_1 = __importDefault(require("open"));
var config_1 = require("../config");
var CLIENT_ID = 'dwauk7iBT36rlvE4XTh3QJ0IxWAv8AGc';
var DOMAIN = "https://dev-xp12liakgecl7vlc.us.auth0.com";
var AUDIENCE = 'https://mamoru.ai';
function requestDeviceCode() {
    var options = {
        method: 'POST',
        url: "".concat(DOMAIN, "/oauth/device/code"),
        data: { client_id: CLIENT_ID, audience: AUDIENCE, scope: 'profile' },
    };
    return axios_1.default
        .request(options)
        .then(function (res) { return res.data; })
        .catch(function (error) {
        throw error;
    });
}
exports.requestDeviceCode = requestDeviceCode;
function openDeviceActivationUrl(url) {
    (0, open_1.default)(url);
}
exports.openDeviceActivationUrl = openDeviceActivationUrl;
/**
 * Request tokens, if the device code is not yet activated, poll until it is.
 * @see https://auth0.com/docs/get-started/authentication-and-authorization-flow/call-your-api-using-the-device-authorization-flow#request-tokens
 */
function requestTokens(deviceCode) {
    var options = {
        method: 'POST',
        url: "".concat(DOMAIN, "/oauth/token"),
        data: {
            grant_type: 'urn:ietf:params:oauth:grant-type:device_code',
            device_code: deviceCode,
            client_id: CLIENT_ID,
        },
    };
    return axios_1.default
        .request(options)
        .then(function (res) { return res.data; })
        .catch(function (error) {
        if (error.response.data.error === 'authorization_pending') {
            return null;
        }
        throw new Error(error.response.data.error_description);
    });
}
exports.requestTokens = requestTokens;
/**
 * Get the user from
 */
function isUserAuthenticated() {
    // read config
    var config = (0, config_1.readRcConfig)();
    // if no authToken, return false
    if (!config.authToken)
        return false;
    // if token check if still valid, if not, remove authToken and return false
    // if valid, return true
    return true;
}
exports.isUserAuthenticated = isUserAuthenticated;
function storeUserToken(authToken) {
    var config = (0, config_1.readRcConfig)();
    config.authToken = authToken;
    (0, config_1.writeRcConfig)(config);
}
exports.storeUserToken = storeUserToken;
function removeUserToken() {
    var config = (0, config_1.readRcConfig)();
    delete config.authToken;
    (0, config_1.writeRcConfig)(config);
}
exports.removeUserToken = removeUserToken;
//# sourceMappingURL=auth.service.js.map